import { capitalizeRequestMethodOperator, requestValidationOperator, HttpRequestHandler, } from './lib/operators';
/** @inheritdoc */
export class HttpClientConfigurator {
    _clients = {};
    /** Get a clone of all configured clients */
    get clients() {
        return { ...this._clients };
    }
    /** default class for creation of http clients */
    defaultHttpClientCtor;
    /** default request handler for http clients, applied on creation */
    defaultHttpRequestHandler = new HttpRequestHandler({
        // convert all request methods to uppercase
        'capitalize-method': capitalizeRequestMethodOperator(),
        // validate the request object
        'request-validation': requestValidationOperator(),
    });
    /**
     * Create a instance of http configuration
     * @param client defaultHttpRequestHandler
     */
    constructor(client) {
        this.defaultHttpClientCtor = client;
    }
    /** @inheritdoc */
    hasClient(name) {
        return Object.keys(this._clients).includes(name);
    }
    /** @inheritdoc */
    configureClient(name, args) {
        const argFn = typeof args === 'string' ? { baseUri: args } : args;
        const options = typeof argFn === 'function' ? { onCreate: argFn } : argFn;
        this._clients[name] = {
            ...this._clients[name],
            ...options,
        };
        return this;
    }
}
export default HttpClientConfigurator;
//# sourceMappingURL=configurator.js.map