import { requestMethodCasing } from './fetch-request.schema';
/**
 * Ensures that the HTTP method of the given request is in uppercase.
 *
 * @param request - The HTTP request object to process.
 * @returns A new request object with the HTTP method in uppercase.
 */
export const capitalizeRequestMethodOperator = (options) => (request) => {
    const { error, success, data } = requestMethodCasing().safeParse(request.method);
    request.method = success ? data : request.method?.toUpperCase();
    if (error && !options?.silent) {
        for (const e of error.errors) {
            console.warn(e.message);
        }
    }
    return request;
};
//# sourceMappingURL=capitalize-request-method.operator.js.map