import type { ResponseSelector } from '../client/types';
/**
 * Asynchronously parses the JSON data from a given HTTP response.
 *
 * If the response has a status code of 204 (No Content), this function will resolve with `undefined`.
 *
 * If the response is not successful (i.e. `response.ok` is `false`), this function will throw an `HttpJsonResponseError` with the response details and the parsed data (if any).
 *
 * If there is an error parsing the JSON data, this function will throw an `HttpJsonResponseError` with the parsing error and the original response.
 *
 * @template TType - The expected type of the parsed JSON data.
 * @template TResponse - The type of the HTTP response object.
 * @param response - The HTTP response to parse.
 * @returns A promise that resolves with the parsed JSON data, or rejects with an `HttpJsonResponseError`.
 */
export declare const jsonSelector: ResponseSelector;
export default jsonSelector;
